pub struct Style(pub AnsiBuilder);Expand description
Style struct takes in the AnsiBuilder and set the correct escape sequence to fit the wanted style that is asked for in future text.
Example
use ansi_builder::AnsiBuilder;
// "Hello" will be bold in the terminal.
AnsiBuilder::new()
.style().bold()
.text("Hello")
.println();Tuple Fields
0: AnsiBuilderImplementations
Sourceimpl Style
impl Style
pub fn bold(self) -> AnsiBuilder
Sourcepub fn conceal(self) -> AnsiBuilder
pub fn conceal(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 39)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn double_underline(self) -> AnsiBuilder
pub fn double_underline(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 19)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn dim(self) -> AnsiBuilder
pub fn dim(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 13)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn encircle(self) -> AnsiBuilder
pub fn encircle(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 61)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn frame(self) -> AnsiBuilder
pub fn frame(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 51)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn italic(self) -> AnsiBuilder
pub fn italic(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 8)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}pub fn normal(self) -> AnsiBuilder
Sourcepub fn overline(self) -> AnsiBuilder
pub fn overline(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 56)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn rapid_blink(self) -> AnsiBuilder
pub fn rapid_blink(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 29)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn remove_blink(self) -> AnsiBuilder
pub fn remove_blink(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 31)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn remove_frame_and_encircle(self) -> AnsiBuilder
pub fn remove_frame_and_encircle(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 53)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn remove_italic(self) -> AnsiBuilder
pub fn remove_italic(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 10)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn remove_overline(self) -> AnsiBuilder
pub fn remove_overline(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 58)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn remove_strike(self) -> AnsiBuilder
pub fn remove_strike(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 26)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn remove_underline(self) -> AnsiBuilder
pub fn remove_underline(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 5)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn reveal(self) -> AnsiBuilder
pub fn reveal(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 41)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn slow_blink(self) -> AnsiBuilder
pub fn slow_blink(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 34)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn strike(self) -> AnsiBuilder
pub fn strike(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 24)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Sourcepub fn underline(self) -> AnsiBuilder
pub fn underline(self) -> AnsiBuilder
Examples found in repository?
examples/styles.rs (line 3)
1fn main() {
2 AnsiBuilder::new()
3 .style().underline()
4 .text("Underlined")
5 .style().remove_underline()
6 .println()
7
8 .style().italic()
9 .text("italic")
10 .style().remove_italic()
11 .println()
12
13 .style().dim()
14 .text("dim text ")
15 .reset_attributes()
16 .text("not dim")
17 .println()
18
19 .style().double_underline()
20 .text("double_underline")
21 .style().remove_underline()
22 .println()
23
24 .style().strike()
25 .text("striked text")
26 .style().remove_strike()
27 .println()
28
29 .style().rapid_blink()
30 .text("rapid bliking text (not widely supported) ")
31 .style().remove_blink()
32 .println()
33
34 .style().slow_blink()
35 .text("slow blink text")
36 .style().remove_blink()
37 .println()
38
39 .style().conceal()
40 .text("Hidden text")
41 .style().reveal()
42 .println()
43
44 .style().strike()
45 .style().double_underline()
46 .text("multi-style")
47 .reset_attributes()
48 .println()
49
50
51 .style().frame()
52 .text("framed text")
53 .style().remove_frame_and_encircle()
54 .println()
55
56 .style().overline()
57 .text("Overlined text")
58 .style().remove_overline()
59 .println()
60
61 .style().encircle()
62 .text("encircle")
63 .style().remove_frame_and_encircle()
64 .println()
65
66 .reset_attributes()
67 .print();
68}Auto Trait Implementations
impl Freeze for Style
impl RefUnwindSafe for Style
impl Send for Style
impl Sync for Style
impl Unpin for Style
impl UnsafeUnpin for Style
impl UnwindSafe for Style